==> clevercherry-media-manager-3.2.8-6359a7.zip: src/Controllers/MediaController.php <==
<?php

namespace Clevercherry\MediaManager\Controllers;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Str;
use Clevercherry\MediaManager\Media;

class MediaController extends Controller
{
    /**
     * Handles the upload or update of an image
     * @param Request $request 
     * @return type
     */
    public function image(Request $request)
    {
        try{
            $request->filename = md5(time());
            if(! empty($request->croppedImage)){
                $path = $this->upload('public/images', $request->croppedImage, $request->filename);
                $original = $this->upload('public/images/original', $request->originalImage, $request->filename);
                $originalPath = $original->path;
            } else{
                $path = $this->upload('public/original', $request->originalImage, $request->filename);
                $originalPath = null;
            }

            $store = [];
            $store['category'] = $request->category;
            $store['tags'] = $request->tags;
            $store['path'] = $path->path;
            $store['original'] = $originalPath;
            $store['type'] = $request->type;
            $store['key'] = $request->key;
            $store['ident'] = $request->ident;

            if(! empty($request->fields)) {
                $store['fields'] = json_encode($request->fields);
            } else {
                $store['fields'] = '[]';
            }

            $store['extension'] = str_replace('.','',$path->extension);

            (! empty($request->group) && $request->group!=='undefined') ? $store['group'] = $request->group : $store['group'] = Media::getOrCreateGroup($store['type'], $store['key'], $store['ident']);

            $store['order'] = Media::getNewOrder($store['group']);
            (! empty($request->list)) ? $store['list'] = 1 : $store['list'] = 0;


            $media = Media::create($store);

            return $store['group'];

        } catch(\Exception $e){
            return $e->getMessage();
        }
    }

    /**
     * Handles the upload of an audio clip
     * @param Request $request 
     * @return type
     */
    public function audio(Request $request)
    {
        try{

            $extension = $request->file('audio')->getClientOriginalExtension();
            $filename = Media::uniqueName(storage_path('app/public/audio'), $request->file('audio')->getClientOriginalName(), '.'.$extension);
            $path = Storage::putFileAs('public/audio', $request->file('audio'), $filename.'.'.$extension);

            $store = [];
            $store['category'] = $request->category;
            $store['tags'] = $request->tags;
            $store['path'] = $path;
            $store['type'] = $request->type;
            $store['key'] = $request->key;
            $store['ident'] = $request->ident;
            
            if(! empty($request->fields)) {
                $store['fields'] = json_encode($request->fields);
            } else {
                $store['fields'] = '[]';
            }           

            $store['filename'] = $filename.'.'.$extension;
            $store['extension'] = $extension;

            (! empty($request->group)) ? $store['group'] = $request->group : $store['group'] = Media::getOrCreateGroup($store['type'], $store['key'], $store['ident']);
            $store['order'] = Media::getNewOrder($store['group']);
            (! empty($request->list)) ? $store['list'] = 1 : $store['list'] = 0;

            $media = Media::create($store);

            return $store['group'];

        } catch(\Exception $e){
            return $e->getMessage();
        }
    }

    /**
     * Handles the upload of a video
     * @param Request $request 
     * @return type
     */
    public function video(Request $request)
    {
        try{
            $request->video_name = md5(time());
            if( $request->hasFile('video') )
            { 
                $extension = $request->file('video')->getClientOriginalExtension();
                $filename = Media::uniqueName(storage_path('app/public/videos'), $request->video_name, '.'.$extension);
                $path = Storage::putFileAs('public/videos', $request->file('video'), $filename.'.'.$extension);
            } else
            {
                $extension='';
                $filename='';
                $path='';
            }

            if( $request->hasFile('thumbnail') )
            {   $th_extension = $request->file('thumbnail')->getClientOriginalExtension();
                $th_filename = Media::uniqueName(storage_path('app/public/videos/thumbnails'), $request->video_name, '.'.$th_extension);
                $th_path = Storage::putFileAs('public/videos/thumbnails', $request->file('thumbnail'), $th_filename.'.'.$th_extension);

            } else
            {
                $th_path='';
                $th_extension='';
                $th_filename='';
            }

            $store = [];
            $store['category'] = $request->category;
            $store['tags'] = $request->tags;
            $store['path'] = $path;
            $store['type'] = $request->type;
            $store['key'] = $request->key;
            $store['ident'] = $request->ident;

            $store['thumbnail']  = $th_path;

            $store['embedded']      = $this->stripVideoUrl(@$request->embedded);
            $store['embedded_type'] = @$request->embedded_type;
            if( !empty($store['embedded']) or !empty($store['embedded_type']) )
            {
                $extension= 'embedded';
            }
            
            if(! empty($request->fields)) {
                $store['fields'] = json_encode($request->fields);
            } else {
                $store['fields'] = '[]';
            }           

            $store['filename'] = $filename.'.'.$extension;
            $store['extension'] = $extension;

            (! empty($request->group)) ? $store['group'] = $request->group : $store['group'] = Media::getOrCreateGroup($store['type'], $store['key'], $store['ident']);
            $store['order'] = Media::getNewOrder($store['group']);
            (! empty($request->list)) ? $store['list'] = 1 : $store['list'] = 0;

            $media = Media::create($store);

            return $store['group'];

        } catch(\Exception $e){
            return $e->getMessage();
        }

    }
    /**
     * Strip out any html to get only the video reference code for any video embedding
     * @param   string $url     the code or url or embedding html for an embedded video
     * @return  string          just the video refernce number/code needed to embed a video
     */
    public function stripVideoUrl($url)
    {   
        $em = trim($url);
        // strip youtube and vimeo  down to the actual video reference/id code
        $p = strpos($em,'http://');
        if($p>0)
            $em = substr($em, $p);
        $p = strpos($em,'https://');
        if($p>0)
            $em = substr($em, $p);
        
        $p = strpos($em,'.wistia.com/');        
        if($p>0) // https://ellismachinery.wistia.com/medias/z2aivxn1ku
            $em = substr($em, $p);
        $em = str_replace('.wistia.com/medias/', '' , $em);
        $em = str_replace('https://fast.wistia.net/embed/iframe/', '', $em);
        $em = str_replace('https://fast.wistia.com/embed/medias/' , '', $em);
        
        $em = str_replace('<iframe width="560" height="315" src="https://www.youtube.com/embed/', '', $em);
        $em = str_replace('https://www.youtube.com/watch?v=', '' , $em);
        $em = str_replace('https://youtu.be/', '' , $em);
        $em = str_replace('https://www.youtube.com/embed/', '' , $em);
        $em = str_replace('<iframe src="https://player.vimeo.com/video/', '' , $em);
        $em = str_replace('https://player.vimeo.com/video/', '' , $em);
        $em = str_replace('https://vimeo.com/', '' , $em);
        $p=strpos($em,'.jsonp');
        if($p>0)
            $em = substr($em, 0, $p);
        $p=strpos($em,'?');
        if($p>0)
                $em = substr($em, 0, $p);
            $p=strpos($em,'&');
        if($p>0)
            $em = substr($em, 0, $p);
        $p=strpos($em,'/');
        if($p>0)
            $em = substr($em, 0, $p);

        return $em;
    }

    /**
     * Process the image upload from a blob
     * @param type $path 
     * @param type $blob 
     * @param type $name 
     * @return type
     */
    public function upload($path, $blob, $name)
    {
        if(! is_dir(storage_path('app/'.$path))){
            mkdir(storage_path('app/'.$path));
        }

        $store = [];
        $pos  = strpos($blob, ';');
        $type = explode(':', substr($blob, 0, $pos))[1];
        $extension = str_replace('image/', '.', $type);
        $uniqueFilename = Media::uniqueName($path, $name, $extension);
        $filename = $uniqueFilename.$extension;

        $pos = strpos($blob, 'base64');
        $pos += 6;
        $blob = substr($blob, $pos);
        $blob = base64_decode($blob);
        
        file_put_contents(storage_path('app/'.$path.'/'.$filename), $blob);

        Media::optimise(storage_path('app/'.$path.'/'.$filename));

        $return = new \stdClass();
        $return->path = $path.'/'.$filename;
        $return->filename = $filename;
        $return->extension = $extension;

        return $return;
    }

    /**
     * Assigns media to new types, keys, idents and groups and reorders the media set by the user
     * @param Request $request 
     * @return type
     */
    public function reorder(Request $request)
    {
        foreach($request->data AS $data){
            $type = $data['type'];
            $key = $data['key'];
            $ident = $data['ident'];
            $category = $data['category'];

            if(! isset($data['group'])){
                $data['group'] = null;
            }

            $group = $data['group'];

            if(empty($data['group']) || $data['group']=='undefined'){
                $group = Media::getOrCreateGroup($type, $key, $ident);
            }

            if(! isset($data['media']) || empty($data['media'])){
                $media = Media::getMedia($group);
                foreach($media AS $value){
                    Media::where('id', $value->id)->delete();
                }
            }

            $ids = [];

            if(isset($data['media'])){ 

                foreach($data['media'] AS $item){

                    $media = Media::where('id', $item)->first();

                    if($media->type==$type && $media->key==$key && $media->ident==$ident){
                        $ids[] = $media->id;
                    } else{
                        $store = [];
                        $store['category'] = $media->category;
                        $store['tags'] = $media->tags;
                        $store['type'] = $type;
                        $store['key'] = $key;
                        $store['group'] = $group;
                        $store['ident'] = $ident;
                        $store['path'] = $media->path;
                        $store['original'] = $media->original;
                        $store['filename'] = $media->filename;
                        $store['extension'] = $media->extension;
                        $store['fields'] = $media->fields;

                        $media = Media::create($store);
                        $ids[] = $media->id;
                    }
                }
            }

            $entries = Media::where([['type', $type],['key', $key],['ident', $ident]])->get();

            $config = Media::getMediaCategory($type, $category);

            foreach($entries AS $entry){
                if(! in_array($entry->id, $ids)){
                    Media::where('id', $entry->id)->update(['type' => null, 'key' => null, 'group' => null, 'ident' => null]);
                } else {
                    Media::optimise(storage_path('app/' . $entry->path), $config['width']);
                }
            }

            foreach($ids AS $order => $id){
                Media::where('id', $id)->update(['order' => $order]);
            }

        }

        $media = Media::getMedia($group);
        $value = Media::getMediaCategory($type, $category);

        return view('media-manager::partials.media-refresh-gallery')->with('media', $media)
                                                                    ->with('value', $value)
                                                                    ->with('group', $group);
    }

    /**
     * Refrehsed the gallery in a given group
     * @param int $group 
     * @return type
     */
    public function refreshGroup(int $group)
    {
        $media = Media::getMedia($group);
        $value = Media::getMediaOptions($media[0]->type, $media[0]->key);
        $value = $value[$media[0]->category];

        return view('media-manager::partials.media-refresh-gallery')->with('media', $media)
                                                                    ->with('value', $value)
                                                                    ->with('group', $group);
    }

    /**
     * Updates the information stored about a media item
     * @param int $id 
     * @param Request $request 
     * @return type
     */
    public function update(int $id, Request $request)
    {
        try {   
            $old = Media::where('id', $id)->first();
            
            $store = [];
            
            if( $request->hasFile('thumbnail') )
            {   $th_extension = $request->file('thumbnail')->getClientOriginalExtension();
                $th_filename = Media::uniqueName(storage_path('app/public/videos/thumbnails'), md5(time()), '.'.$th_extension);
                $th_path = Storage::putFileAs('public/videos/thumbnails', $request->file('thumbnail'), $th_filename.'.'.$th_extension);
                $store['thumbnail']  = $th_path;

                if($old['thumbnail'] !== $store['thumbnail'] )
                {
                    Storage::delete($old['thumbnail']);
                }
            }

            if(!empty(@$request->embedded))
            {   $store['embedded'] = $this->stripVideoUrl(@$request->embedded);
            }
            if(!empty(@$request->embedded_type))
            {   $store['embedded_type'] = @$request->embedded_type;
            }

            if(! empty($request->fields))
            {   $store['fields'] = json_encode($request->fields);
            } else
            {   $store['fields'] = '[]';
            }

            Media::where('id', $id)->update($store);

            $group = (! empty($request->group)) ?  $request->group : Media::getOrCreateGroup($old['type'], $old['key'], $old['ident']);
            return array( 'group'=>$group, 'ident'=>$old['ident']);

        } catch(\Exception $e) {   
            abort(404);
        }
    }
}

==> clevercherry-media-manager-3.8-4a31b6.zip: src/Controllers/MediaController.php <==
<?php

namespace Clevercherry\MediaManager\Controllers;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Str;
use Clevercherry\MediaManager\Media;

class MediaController extends Controller
{
    /**
     * Handles the upload or update of an image
     * @param Request $request 
     * @return type
     */
    public function image(Request $request)
    {
        try{
            $request->filename = md5(time());
            if(! empty($request->croppedImage)){
                $path = $this->upload('public/images', $request->croppedImage, $request->filename);
                $original = $this->upload('public/images/original', $request->originalImage, $request->filename);
                $originalPath = $original->path;
            } else{
                $path = $this->upload('public/original', $request->originalImage, $request->filename);
                $originalPath = null;
            }

            $store = [];
            $store['category'] = $request->category;
            $store['tags'] = $request->tags;
            $store['path'] = $path->path;
            $store['original'] = $originalPath;
            $store['type'] = $request->type;
            $store['key'] = $request->key;
            $store['ident'] = $request->ident;

            if(! empty($request->fields)) {
                $store['fields'] = json_encode($request->fields);
            } else {
                $store['fields'] = '[]';
            }

            $store['extension'] = str_replace('.','',$path->extension);

            (! empty($request->group) && $request->group!=='undefined') ? $store['group'] = $request->group : $store['group'] = Media::getOrCreateGroup($store['type'], $store['key'], $store['ident']);

            $store['order'] = 1;
            (! empty($request->list)) ? $store['list'] = 1 : $store['list'] = 0;

            $mediaItems = Media::where('group', $store['group'])->get();

            foreach($mediaItems AS $key => $mediaItem) {
                if($key == 0 && $mediaItem->order == 1) {
                    $mediaItem->order = 0;
                }

                if($key > 0) {
                    $mediaItem->order++;
                }

                $mediaItem->save();
            }

            $media = new Media;

            foreach($store AS $key => $value) {
                $media->{$key} = $value;
            }
            
            $media->save();

            return $store['group'];

        } catch(\Exception $e){
            return $e->getMessage();
        }
    }

    /**
     * Handles the upload of an audio clip
     * @param Request $request 
     * @return type
     */
    public function audio(Request $request)
    {
        try{

            $extension = $request->file('audio')->getClientOriginalExtension();
            $filename = Media::uniqueName(env('APP_NAME') . '/audio', $request->file('audio')->getClientOriginalName(), '.'.$extension);
            $path = Storage::putFileAs('public/audio', $request->file('audio'), $filename.'.'.$extension);

            $store = [];
            $store['category'] = $request->category;
            $store['tags'] = $request->tags;
            $store['path'] = $path;
            $store['type'] = $request->type;
            $store['key'] = $request->key;
            $store['ident'] = $request->ident;
            
            if(! empty($request->fields)) {
                $store['fields'] = json_encode($request->fields);
            } else {
                $store['fields'] = '[]';
            }           

            $store['filename'] = $filename.'.'.$extension;
            $store['extension'] = $extension;

            (! empty($request->group)) ? $store['group'] = $request->group : $store['group'] = Media::getOrCreateGroup($store['type'], $store['key'], $store['ident']);
            $store['order'] = Media::getNewOrder($store['group']);
            (! empty($request->list)) ? $store['list'] = 1 : $store['list'] = 0;

            $media = new Media;

            foreach($store AS $key => $value) {
                $media->{$key} = $value;
            }
            
            $media->save();

            return $store['group'];

        } catch(\Exception $e){
            return $e->getMessage();
        }
    }

    /**
     * Handles the upload of a video
     * @param Request $request 
     * @return type
     */
    public function video(Request $request)
    {
        try{
            $request->video_name = md5(time());
            if( $request->hasFile('video') )
            { 
                $extension = $request->file('video')->getClientOriginalExtension();
                $filename = Media::uniqueName(env('APP_NAME') . '/videos', $request->video_name, '.'.$extension);
                $path = Storage::putFileAs('public/videos', $request->file('video'), $filename.'.'.$extension);
            } else
            {
                $extension='';
                $filename='';
                $path='';
            }

            if( $request->hasFile('thumbnail') )
            {   
                $th_extension = $request->file('thumbnail')->getClientOriginalExtension();
                $th_filename = Media::uniqueName(env('APP_NAME') . '/public/videos/thumbnails', $request->video_name, '.'.$th_extension);
                $th_path = Storage::putFileAs('public/videos/thumbnails', $request->file('thumbnail'), $th_filename.'.'.$th_extension);
                Media::optimise($th_path, $request->width);
            } else
            {
                $th_path='';
                $th_extension='';
                $th_filename='';
            }

            $store = [];
            $store['category'] = $request->category;
            $store['tags'] = $request->tags;
            $store['path'] = $path;
            $store['type'] = $request->type;
            $store['key'] = $request->key;
            $store['ident'] = $request->ident;

            $store['thumbnail']  = $th_path;

            $store['embedded']      = $this->stripVideoUrl(@$request->embedded);
            $store['embedded_type'] = @$request->embedded_type;
            if( !empty($store['embedded']) or !empty($store['embedded_type']) )
            {
                $extension= 'embedded';
            }
            
            if(! empty($request->fields)) {
                $store['fields'] = json_encode($request->fields);
            } else {
                $store['fields'] = '[]';
            }           

            $store['filename'] = $filename.'.'.$extension;
            $store['extension'] = $extension;

            (! empty($request->group)) ? $store['group'] = $request->group : $store['group'] = Media::getOrCreateGroup($store['type'], $store['key'], $store['ident']);
            $store['order'] = Media::getNewOrder($store['group']);
            (! empty($request->list)) ? $store['list'] = 1 : $store['list'] = 0;

            $media = new Media;

            foreach($store AS $key => $value) {
                $media->{$key} = $value;
            }
            
            $media->save();

            return $store['group'];

        } catch(\Exception $e){
            return $e->getMessage();
        }

    }
    /**
     * Strip out any html to get only the video reference code for any video embedding
     * @param   string $url     the code or url or embedding html for an embedded video
     * @return  string          just the video refernce number/code needed to embed a video
     */
    public function stripVideoUrl($url)
    {   
        $em = trim($url);
        // strip youtube and vimeo  down to the actual video reference/id code
        $p = strpos($em,'http://');
        if($p>0)
            $em = substr($em, $p);
        $p = strpos($em,'https://');
        if($p>0)
            $em = substr($em, $p);
        
        $p = strpos($em,'.wistia.com/');        
        if($p>0) // https://ellismachinery.wistia.com/medias/z2aivxn1ku
            $em = substr($em, $p);
        $em = str_replace('.wistia.com/medias/', '' , $em);
        $em = str_replace('https://fast.wistia.net/embed/iframe/', '', $em);
        $em = str_replace('https://fast.wistia.com/embed/medias/' , '', $em);
        
        $em = str_replace('<iframe width="560" height="315" src="https://www.youtube.com/embed/', '', $em);
        $em = str_replace('https://www.youtube.com/watch?v=', '' , $em);
        $em = str_replace('https://youtu.be/', '' , $em);
        $em = str_replace('https://www.youtube.com/embed/', '' , $em);
        $em = str_replace('<iframe src="https://player.vimeo.com/video/', '' , $em);
        $em = str_replace('https://player.vimeo.com/video/', '' , $em);
        $em = str_replace('https://vimeo.com/', '' , $em);
        $p=strpos($em,'.jsonp');
        if($p>0)
            $em = substr($em, 0, $p);
        $p=strpos($em,'?');
        if($p>0)
                $em = substr($em, 0, $p);
            $p=strpos($em,'&');
        if($p>0)
            $em = substr($em, 0, $p);
        $p=strpos($em,'/');
        if($p>0)
            $em = substr($em, 0, $p);

        return $em;
    }

    /**
     * Process the image upload from a blob
     * @param type $path 
     * @param type $blob 
     * @param type $name 
     * @return type
     */
    public function upload($path, $blob, $name)
    {
        $store = [];
        $pos  = strpos($blob, ';');
        $type = explode(':', substr($blob, 0, $pos))[1];
        $extension = str_replace('image/', '.', $type);
        $uniqueFilename = Media::uniqueName($path, $name, $extension);
        $filename = $uniqueFilename.$extension;

        $pos = strpos($blob, 'base64');
        $pos += 6;
        $blob = substr($blob, $pos);
        $blob = base64_decode($blob);
        
        Storage::put($path.'/'.$filename, $blob);

        Media::optimise($path.'/'.$filename);

        $return = new \stdClass();
        $return->path = $path.'/'.$filename;
        $return->filename = $filename;
        $return->extension = $extension;

        return $return;
    }

    /**
     * Assigns media to new types, keys, idents and groups and reorders the media set by the user
     * @param Request $request 
     * @return type
     */
    public function reorder(Request $request)
    {
        foreach($request->data AS $data) {
            $type = $data['type'];
            $key = $data['key'];
            $ident = $data['ident'];
            $category = $data['category'];

            if(! isset($data['group'])){
                $data['group'] = null;
            }

            $group = $data['group'];

            if(empty($data['group']) || $data['group']=='undefined'){
                $group = Media::getOrCreateGroup($type, $key, $ident);
            }

            if(! isset($data['media']) || empty($data['media'])){
                $media = Media::getMedia($group);
                foreach($media AS $value){
                    Media::where('id', $value->id)->delete();
                }
            }

            $ids = [];

            if(isset($data['media'])){ 

                foreach($data['media'] AS $item){

                    $media = Media::where('id', $item)->first();

                    if($media->type==$type && $media->key==$key && $media->ident==$ident){
                        $ids[] = $media->id;
                    } else{
                        $store = [];
                        $store['category'] = $media->category;
                        $store['tags'] = $media->tags;
                        $store['type'] = $type;
                        $store['key'] = $key;
                        $store['group'] = $group;
                        $store['ident'] = $ident;
                        $store['path'] = $media->path;
                        $store['original'] = $media->original;
                        $store['filename'] = $media->filename;
                        $store['extension'] = $media->extension;
                        $store['thumbnail'] = $media->thumbnail;
                        $store['fields'] = $media->fields;

                        $media = new Media;

                        foreach($store AS $key => $value) {
                            $media->{$key} = $value;
                        }
                        
                        $media->save();
                        
                        $ids[] = $media->id;
                    }
                }
            }

            $entries = Media::where([['type', $type],['key', $key],['ident', $ident]])->get();

            $config = Media::getMediaCategory($type, $category);

            foreach($entries AS $entry){
                if(! in_array($entry->id, $ids)){
                    Media::where('id', $entry->id)->update(['type' => null, 'key' => null, 'group' => null, 'ident' => null]);
                } else {
                    if(in_array($entry->extension, ['mp4', 'mov'])) {
                        $path = $entry->thumbnail;
                        $original = null;
                    } else {
                        $path = $entry->path;
                        $original = $entry->original;
                    }
                    if(! empty($path)) {
                        Media::optimise($path, $config['width']);
                    }
                }
            }

            foreach($ids AS $order => $id){
                Media::where('id', $id)->update(['order' => $order]);
            }

        }

        $media = Media::getMedia($group);
        $value = Media::getMediaCategory($type, $category);

        return view('media-manager::partials.media-refresh-gallery')->with('media', $media)
                                                                    ->with('value', $value)
                                                                    ->with('group', $group);
    }

    /**
     * Refreshes the gallery in a given group
     * @param int $group 
     * @return type
     */
    public function refreshGroup(int $group)
    {
        $media = Media::getMedia($group);
        $value = Media::getMediaOptions($media[0]->type, $media[0]->key);
        $value = $value[$media[0]->category];

        return view('media-manager::partials.media-refresh-gallery')->with('media', $media)
                                                                    ->with('value', $value)
                                                                    ->with('group', $group);
    }

    /**
     * Updates the information stored about a media item
     * @param int $id 
     * @param Request $request 
     * @return type
     */
    public function update(int $id, Request $request)
    {
        try {   
            $old = Media::where('id', $id)->first();
            
            $store = [];
            
            if( $request->hasFile('thumbnail') )
            {   $th_extension = $request->file('thumbnail')->getClientOriginalExtension();
                $th_filename = Media::uniqueName(env('APP_NAME') . '/videos/thumbnails', md5(time()), '.'.$th_extension);
                $th_path = Storage::putFileAs('public/videos/thumbnails', $request->file('thumbnail'), $th_filename.'.'.$th_extension);
                $store['thumbnail']  = $th_path;

                if($old['thumbnail'] !== $store['thumbnail'] )
                {
                    Storage::delete($old['thumbnail']);
                }
            }

            if(!empty(@$request->embedded))
            {   $store['embedded'] = $this->stripVideoUrl(@$request->embedded);
            }
            if(!empty(@$request->embedded_type))
            {   $store['embedded_type'] = @$request->embedded_type;
            }

            if(! empty($request->fields))
            {   $store['fields'] = json_encode($request->fields);
            } else
            {   $store['fields'] = '[]';
            }

            $media = Media::where('id', $id)->first();
            
            foreach($store AS $key => $value) {
                $media->{$key} = $value;
            }

            $media->save();

            $group = (! empty($request->group)) ?  $request->group : Media::getOrCreateGroup($old['type'], $old['key'], $old['ident']);
            return array( 'group'=>$group, 'ident'=>$old['ident']);

        } catch(\Exception $e) {   
            abort(404);
        }
    }
}
